import { Component, ElementRef, NgZone, OnInit, ViewChild } from '@angular/core';
import { ActivatedRoute } from '@angular/router';
import { Station } from '../model/station';
import { MapsAPILoader, MouseEvent } from '@agm/core';
import { MonitoringStationServiceService } from '../monitoring-station-service/monitoring-station-service.service';
@Component({
  selector: 'app-add-update-monitoring-station',
  templateUrl: './add-update-monitoring-station.component.html',
  styleUrls: ['./add-update-monitoring-station.component.scss']
})
export class AddUpdateMonitoringStationComponent implements OnInit {
  station: Station = new Station(0, "", "", "", "", "", "", "");
  customerId: String
  stationId: String;
  latitude: number;
  longitude: number;
  zoom: number;
  address: string;
  public geoCoder;
  isShow: boolean = false;
  @ViewChild('search', { static: false })
  public searchElementRef: ElementRef;
  constructor(private activeRoute: ActivatedRoute, public mapsAPILoader: MapsAPILoader,
    public ngZone: NgZone, private monitoringStationService: MonitoringStationServiceService) { }

  ngOnInit(): void {
    this.geoCoder = new google.maps.Geocoder;
    console.log("Add update Monitoring station");
    this.customerId = this.activeRoute.snapshot.paramMap.get('customer-id');
    this.stationId = this.activeRoute.snapshot.paramMap.get('stationId');
    if (this.stationId != null) {
      this.station = this.monitoringStationService.getItemById(this.stationId);
    }
    this.mapsAPILoader.load().then(() => {
      this.setCurrentLocation();
      let autocomplete = new google.maps.places.Autocomplete(this.searchElementRef.nativeElement);
      autocomplete.addListener("place_changed", () => {
        this.ngZone.run(() => {
          //get the place result
          console.log(autocomplete.getPlace());
          let place: google.maps.places.PlaceResult = autocomplete.getPlace();
          console.log(place);
          //verify result
          if (place.geometry === undefined || place.geometry === null) {
            return;
          }

          //set latitude, longitude and zoom
          this.latitude = place.geometry.location.lat();
          this.longitude = place.geometry.location.lng();
          this.zoom = 12;
        });
      });
    });
  }
  // Get Current Location Coordinates
  private setCurrentLocation() {
    if ('geolocation' in navigator) {
      if (this.station.lat === "") {
        navigator.geolocation.getCurrentPosition((position) => {
          this.latitude = position.coords.latitude;
          this.longitude = position.coords.longitude;
          this.zoom = 8;
          this.getAddress(this.latitude, this.longitude);
        });
      } else {
        this.latitude = Number(this.station.lat)
        this.longitude = Number(this.station.long);
        this.zoom = 8;
        this.getAddress(this.latitude, this.longitude);
      }
    }
  }


  markerDragEnd($event: MouseEvent) {
    console.log($event);
    this.latitude = $event.coords.lat;
    this.longitude = $event.coords.lng;
    this.getAddress(this.latitude, this.longitude);
    this.station.lat = String(this.latitude);
    this.station.long = String(this.longitude);
  }

  getAddress(latitude, longitude) {
    this.geoCoder.geocode({ 'location': { lat: latitude, lng: longitude } }, (results, status) => {
      console.log(results);
      console.log(status);
      if (status === 'OK') {
        if (results[0]) {
          this.zoom = 12;
          this.address = results[0].formatted_address;
          this.station.address = results[0].formatted_address;
        } else {
          window.alert('No results found');
        }
      } else {
        window.alert('Geocoder failed due to: ' + status);
      }

    });
  }
  saveChanges() { }
}
